﻿using System;

namespace ChainOfCommandSample
{
    /// <summary>
    /// Another command.
    /// </summary>
    public class DoSomethingElseWithKeyCommand : Command
    {
        private Guid _key;

        /// <summary>
        /// Gets the priority.  A lower value indicates higher priority.
        /// </summary>
        /// <value>The priority.</value>
        public override int Priority
        {
            get { return 200; }
        }

        /// <summary>
        /// Executes this instance.
        /// </summary>
        public override void Execute()
        {
            Console.Out.WriteLine("From DoSomethingElseWithKeyCommand: {0}", _key);
        }

        /// <summary>
        /// Handles the key generated event.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="key">The <see cref="Guid"/> instance containing the event data.</param>
        [EventSubscriber(EventNames.KeyGenerated)]
        private void HandleKeyGenerated(object sender, EventArgs<Guid> e)
        {
            _key = e.Data;
        }
    }
}