﻿using System;

namespace ChainOfCommandSample
{
    /// <summary>
    /// Generates a GUID that may be needed by the rest of the chain.
    /// </summary>
    public class GenerateKeyCommand : Command
    {
        /// <summary>
        /// Raised when a key is generated;
        /// </summary>
        [EventPublisher(EventNames.KeyGenerated)]
        public event EventHandler<EventArgs<Guid>> KeyGenerated;

        /// <summary>
        /// Executes this instance.
        /// </summary>
        public override void Execute()
        {
            Guid key = Guid.NewGuid();

            Console.Out.WriteLine("From GenerateKeyCommand: {0}", key);

            OnKeyGenerated(key);
        }

        /// <summary>
        /// Gets the priority.  A lower value indicates higher priority.
        /// </summary>
        /// <value>The priority.</value>
        public override int Priority
        {
            get { return 1; }
        }

        /// <summary>
        /// Raises the key generated event.
        /// </summary>
        /// <param name="key">The key.</param>
        private void OnKeyGenerated(Guid key)
        {
            if(KeyGenerated != null)
            {
                KeyGenerated(this, new EventArgs<Guid>(key));
            }
        }
    }
}