﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Reflection;

namespace ChainOfCommandSample
{
    /// <summary>
    /// A simple command chain factory that doesn't do wiring.
    /// </summary>
    public static class SimpleCommandChainFactory
    {
        /// <summary>
        /// Creates a simple list of commands to execute using reflection.
        /// </summary>
        public static List<Command> Create()
        {
            var commands = new List<Command>();

            Type[] types = Assembly.GetExecutingAssembly().GetTypes();
            Type commandType = typeof (Command);

            foreach (Type type in types)
            {
                if (!type.IsSubclassOf(commandType))
                {
                    continue;
                }

                MemberInitExpression init = Expression.MemberInit(
                    Expression.New(type), new MemberBinding[0]);

                Command command = Expression.Lambda<Func<Command>>(init)
                    .Compile().Invoke();

                commands.Add(command);
            }

            commands = commands.OrderBy(c => c.Priority).ToList();

            return commands;
        }
    }
}